use `ombutel`;

create table `ombu_music_groups` (
	`group_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`order` enum('linear','shuffle') not null,
	primary key (`group_id`),
	unique (`name`)
);

create table `ombu_music_files` (
	`file_id` int unsigned not null auto_increment,
	`group_id` int unsigned not null,
	`index` int unsigned not null,
	`original_filename` varchar(255) not null,
	`duration` int unsigned not null,
	primary key (`file_id`),
	unique (`group_id`, `index`),
	foreign key (`group_id`) references `ombu_music_groups`(`group_id`) on delete cascade
);

create table `ombu_intrusion_whitelist` (
	`whitelist_id` int unsigned not null auto_increment,
	`host` varchar(255) not null,
	primary key(`whitelist_id`)
);

create table `ombu_ars` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_astcli` (
	`command` varchar(255) not null,
	`description` varchar(255) default null,
	index (`command`)
);

create table `ombu_astmanager_users` (
	`id` int unsigned not null auto_increment,
	`user_name` varchar(255) not null,
	`description` varchar(255) default null,
	`secret` varchar(255) not null,
	`deny` varchar(255) not null,
	`permit` varchar(255) not null,
	`read` varchar(255) not null,
	`write` varchar(255) not null,
	primary key (`id`),
	unique `user_name` (`user_name`)
);

create table `ombu_dialrules` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_features_category` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_features_group` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`module_associated` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_features` (
	`id` int unsigned not null auto_increment,
	`features_group_id` int unsigned not null,
	`feature_name` varchar(255) not null,
	`description` varchar(255) default null,
	`defaultnumber` varchar(255) default null,
	`customnumber` varchar(255) default null,
	`func` varchar(255) not null,
	`prefix` varchar(255) default null,
	`sufix` varchar(255) default null,
	`sendlength` enum('yes','no') not null default 'no',
	`param01` varchar(255) default null,
	`param02` varchar(255) default null,
	`param03` varchar(255) default null,
	`param04` varchar(255) default null,
	`param05` varchar(255) default null,
	`state` enum('yes','no') not null default 'yes',
	`edit` enum('yes','no') not null default 'no',
	`generate` enum('yes','no') not null default 'yes',
	primary key (`id`),
	unique key `feature_name` (`feature_name`),
	foreign key (`features_group_id`) references `ombu_features_group` (`id`) on delete cascade
);

create table `ombu_features_category_items` (
	`features_category_id` int unsigned not null,
	`feature_id` int unsigned not null,
	foreign key (`features_category_id`) references `ombu_features_category` (`id`) on delete cascade ,
	foreign key (`feature_id`) references `ombu_features` (`id`) on delete cascade
);

create table `ombu_class_of_service` (
	`id` int unsigned not null auto_increment,
	`cos` varchar(255) default null,
	`description` varchar(255) default null,
	`features_category_id` int unsigned default null,
	`ars_id` int unsigned default null,
	`dr_id` int unsigned default null,
	`mod_lastdest` varchar(255) not null,
	`lastdest` varchar(255) not null,
	`mod_badnumber` varchar(255) not null,
	`badnumber` varchar(255) not null,
	`default` enum('yes','no'),
	primary key (`id`),
	unique (`cos`),
	foreign key (`features_category_id`) references `ombu_features_category` (`id`),
	foreign key (`ars_id`) references `ombu_ars` (`id`),
	foreign key (`dr_id`) references `ombu_dialrules` (`id`)
);

create table `ombu_callback` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`dialprefix` varchar(255) default null,
	`dialnumber` varchar(255) default null,
	`delay` int unsigned not null,
	`cos_id` int unsigned default null,
	`mod_dest` varchar(255) not null,
	`destination` varchar(255) not null,
	primary key (`id`),
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`) on delete cascade
);

create table `ombu_codecs` (
	`id` int unsigned not null auto_increment,
	`codec` varchar(255) not null,
	`sequence` int unsigned not null,
	`codec_type` enum('unknown', 'audio', 'video') not null,
	primary key (`id`),
	unique (`codec`)
);

create table `ombu_custom_application` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`description` varchar(255) default null,
	`mod_dest` varchar(255) default null,
	`destination` varchar(255) default null,
	`status` enum('yes', 'no') not null,
	primary key (`id`),
	unique (`extension`)
);

create table `ombu_custom_destination` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`destdial` varchar(255) not null,
	`cos_id` int unsigned not null,
	primary key (`id`),
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`)
);

create table `ombu_dahdi_groups` (
	`group_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	primary key (`group_id`)
);

create table `ombu_dahdi_devices` (
	`device_id` int unsigned not null auto_increment,
	`identifier` varchar(255) not null,
	`manufacturer` varchar(255) not null,
	`type` varchar(255) not null,
	`location` varchar(255) not null,
	unique(`identifier`),
	primary key (`device_id`)
);

create table `ombu_dahdi_spans` (
	`span_id` int unsigned not null auto_increment,
	`device_id` int unsigned not null,
	`index` int unsigned not null,
	`type` enum('bri_nt', 'bri_te', 'e1', 't1', 'analog') not null,
	`basechan` int unsigned not null,
	`channels` int unsigned not null,
	primary key (`span_id`),
	unique (`device_id`, `index`),
	foreign key (`device_id`) references `ombu_dahdi_devices`(`device_id`) on delete cascade
);

create table `ombu_dahdi_span_caps` (
	`span_id` int unsigned not null,
	`supports` enum(
		'd4/ami', 'd4/b8zs', 'esf/ami', 'esf/b8zs',
		'cas/ami', 'cas/hdb3', 'ccs/ami', 'ccs/hdb3',
		'cas/ami/crc4', 'cas/hdb3/crc4', 'ccs/ami/crc4', 'ccs/hdb3/crc4'
	) not null,
	foreign key (`span_id`) references `ombu_dahdi_spans` (`span_id`) on delete cascade
);

create table `ombu_dahdi_digital_spans` (
	`span_id` int unsigned not null,
	`lbo` int unsigned not null,
	`clocksource` int unsigned not null,
	`uses` enum(
		'd4/ami', 'd4/b8zs', 'esf/ami', 'esf/b8zs',
		'cas/ami', 'cas/hdb3', 'ccs/ami', 'ccs/hdb3',
		'cas/ami/crc4', 'cas/hdb3/crc4', 'ccs/ami/crc4', 'ccs/hdb3/crc4'
	) not null,
	foreign key (`span_id`) references `ombu_dahdi_spans` (`span_id`) on delete cascade
);

create table `ombu_recordings` (
	`recording_id` int unsigned not null auto_increment,
	`original_filename` varchar(255) not null,
	`name` varchar(255) not null,
	`duration` int unsigned not null,
	primary key (`recording_id`),
	unique (`name`)
);

create table `ombu_conferences` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`description` varchar(255) default null,
	`userpin` varchar(255) default null,
	`adminpin` varchar(255) default null,
	`max_members` varchar(255) default null,
	`video_mode` varchar(255) not null,
	`language` varchar(255) not null,
	`record_conference` enum('yes', 'no') not null,
	`announcement` int unsigned default null,
	`moh_id` int unsigned default null,
	`music_on_hold_when_empty` enum('yes', 'no') default null,
	`startmuted` enum('yes', 'no') default null,
	`quiet` enum('yes', 'no') default null,
	`announce_user_count_all` varchar(255) default null,
	`announce_user_count` enum('yes', 'no') default null,
	`announce_only_user` enum('yes', 'no') default null,
	`wait_marked` enum('yes', 'no') default null,
	`end_marked` enum('yes', 'no') default null,
	`dsp_drop_silence` enum('yes', 'no') default null,
	`talk_detection_events` enum('yes', 'no') default null,
	`announce_join_leave` enum('yes', 'no') default null,
	primary key (`id`),
	unique (`extension`),
	foreign key (`announcement`) references `ombu_recordings` (`recording_id`) on delete set null,
	foreign key (`moh_id`) references `ombu_music_groups`(`group_id`) on delete set null
);

create table `ombu_dialrules_patterns` (
	`dr_id` int unsigned not null,
	`number` varchar(255) not null,
	`allow` enum('yes','no') default 'no',
	`play_duration` enum('yes','no') default 'no',
	`maxduration` int unsigned default null,
	`announcement_id` int unsigned default null,
	`password` enum('yes','no') default 'yes',
	`order` int unsigned default null,
	foreign key (`dr_id`) references `ombu_dialrules` (`id`) on delete cascade ,
	foreign key (`announcement_id`) references `ombu_recordings` (`recording_id`) on delete set null
);

create table `ombu_digium_products` (
	`product_id` int unsigned not null auto_increment,
	`module` varchar(255) not null,
	`key` varchar(255) not null,
	`name` varchar(255) not null,
	`code` varchar(255) not null,
	primary key (`product_id`)
);

create table `ombu_digium_licenses` (
	`license_id` int unsigned not null auto_increment,
	`product_id` int unsigned not null,
	`key` varchar(255) not null,
	`firstname` varchar(255) not null,
	`lastname` varchar(255) not null,
	`company` varchar(255) default null,
	`phone` varchar(255) not null,
	`email` varchar(255) not null,
	`address1` varchar(255) not null,
	`address2` varchar(255) default null,
	`country` varchar(255) not null,
	`state` varchar(255) default null,
	`city` varchar(255) not null,
	`postal_code` varchar(255) default null,
	`expiration_date` date not null,
	primary key (`license_id`),
	foreign key (`product_id`) references `ombu_digium_products`(`product_id`) on delete cascade
);

create table `ombu_disa` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`cos_id` int unsigned not null,
	`password` varchar(255) not null,
	`cid` varchar(255) default null,
	`resp_timeout` int unsigned default null,
	`digit_timeout` int unsigned default null,
	primary key (`id`),
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`)
);

create table `digium_phone_models` (
	`phone_model_id` int unsigned not null auto_increment,
	`model_name` enum('D70','D50','D45','D40') not null,
	`lines` int unsigned not null,
	`rapid_keys` int unsigned default 0,
	primary key (`phone_model_id`)
);

create table `ombu_dpma_ringtones` (
	`id` int unsigned not null auto_increment,
	`alias` varchar(255) not null,
	`filename` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_dpma_alerts` (
	`id` int unsigned not null auto_increment,
	`ringtone_id` int unsigned default null,
	`digium_ringtone` varchar(255) default 'Alarm',
	`description` varchar(255) default null,
	`alert_info` varchar(255) not null,
	`use_default_ringtones` enum('yes','no') default 'yes',
	`ring_type` enum('normal', 'answer', 'ring-answer', 'visual') not null,
	primary key (`id`),
	foreign key (`ringtone_id`) references `ombu_dpma_ringtones`(`id`) on delete restrict
);

create table `ombu_dpma_translation` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_dpmatranslation_opts` (
	`translation_id` int unsigned not null,
	`param` varchar(255) not null,
	`value` varchar(255) not null,
	`sort` int unsigned not null,
	foreign key (`translation_id`) references `ombu_dpma_translation`(`id`) on delete cascade
);

create table `ombu_dpma_app` (
	`id` int unsigned not null auto_increment,
	`applications` varchar(255) not null,
	`description` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_dpma_app_custom` (
	`app_id` int unsigned not null,
	`name` varchar(255) not null,
	`filename` varchar(255) not null,
	`autostart` enum('yes', 'no') default null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade
);

create table `ombu_dpma_app_custom_conf` (
	`app_id` int unsigned default null,
	`param` varchar(255) default null,
	`value` varchar(255) default null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade
);

create table `ombu_dpma_app_parking` (
	`app_id` int unsigned not null,
	`parkinglot` varchar(255) not null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade
);

create table `ombu_dpma_app_queues` (
	`app_id` int unsigned not null,
	`queue` varchar(255) not null,
	`membername` varchar(255) not null,
	`location` varchar(255) default null,
	`login_exten` varchar(255) default null,
	`logout_exten` varchar(255) default null,
	`member` enum('yes', 'no') default null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade
);

create table `ombu_dpma_app_status` (
	`app_id` int unsigned not null,
	`status` varchar(255) not null,
	`substatus` varchar(255) default null,
	`send486` enum('yes', 'no') default null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade
);

create table `ombu_dpma_app_voicemail` (
	`app_id` int unsigned not null,
	`translation` int unsigned not null,
	`require_password` enum('yes', 'no') default null,
	foreign key (`app_id`) references `ombu_dpma_app`(`id`) on delete cascade,
	foreign key (`translation`) references `ombu_dpma_translation`(`id`) on delete restrict
);

create table `ombu_dpma_networks` (
	`id` int unsigned not null auto_increment,
	`alias` varchar(255) not null,
	`cidr` varchar(255) not null,
	`registration_address` varchar(255) not null,
	`registration_port` int unsigned not null,
	`alternate_registration_address` varchar(255) default null,
	`alternate_registration_port` int unsigned default null,
	`file_url_prefix` varchar(255) default null,
	`public_firmware_url_prefix` varchar(255) default null,
	`ntp_server` varchar(255) default null,
	`network_vlan_discovery_mode` enum('LLDP', 'MANUAL', 'NONE') not null,
	`network_vlan_id` int unsigned default null,
	`pc_vlan_id` int unsigned default null,
	`sip_qos` int unsigned default null,
	`rtp_qos` int unsigned default null,
	`pc_qos` int unsigned default null,
	`enable_logging` enum('yes', 'no') not null,
	`syslog_level` enum('debug', 'error', 'warning', 'information') not null,
	`syslog_server` varchar(255) default null,
	`syslog_port` int unsigned default null,
	`sip_dscp` int unsigned default null,
	`rtp_dscp` int unsigned default null,
	`udp_ka_interval` int unsigned default null,
	`default` enum('yes','no') default 'no',
	primary key (`id`)
);

create table `ombu_dpma_settings` (
	`id` int unsigned not null auto_increment,
	`server_uuid` varchar(255) default null,
	`globalpin` int unsigned default null,
	`userlist_auth` char(10) not null,
	`config_auth` char(10) not null,
	`service_name` varchar(255) default null,
	`mdns_address` varchar(255) not null,
	`mdns_port` int unsigned not null,
	`service_discovery_enabled` enum('yes','no') not null,
	`pjsip_message_context` varchar(255) default null,
	`file_directory` varchar(255) default null,
	primary key (`id`)
) ;

create table `ombu_roles` (
	`id` int unsigned not null auto_increment,
	`owner` int unsigned default null,
	`role` varchar(255) not null,
	`superadmin` enum('yes', 'no') not null,
	`default` enum('yes', 'no') not null,
	primary key (`id`)
);

create table `ombu_tenants` (
	`id` int unsigned not null auto_increment,
	`tenant` varchar(255) not null,
	`description` varchar(255) default null,
	`default` enum('yes', 'no') not null default 'no',
	`host` varchar(255) default null,
	`extensions` varchar(255) default null,
	`ringroups` varchar(255) default null,
	`queues` varchar(255) default null,
	`conferences` varchar(255) default null,
	`ivr` varchar(255) default null,
	`users` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_users` (
	`id` int unsigned not null auto_increment,
	`parent` int unsigned default null,
	`role_id` int unsigned default null,
	`tenant_id` int unsigned default null,
	`name` varchar(255) not null,
	`dept` varchar(255) default null,
	`user` varchar(255) not null,
	`password` binary(64) default null,
	`notifications` varchar(255) default null,
	`locale` varchar(255) not null,
	`timezone` varchar(255) not null,
	`startapp` varchar(255) default null,
	`theme` varchar(255) default null,
	`portalexten` varchar(255) default null,
	`portaluser` enum('yes', 'no') not null default 'no',
	`multitab` enum('yes', 'no') not null default 'yes',
	`enable` enum('yes', 'no') not null default 'yes',
	primary key (`id`),
	foreign key(`parent`) references `ombu_users`(`id`) on delete cascade ,
	foreign key(`role_id`) references `ombu_roles`(`id`) on delete cascade ,
	foreign key(`tenant_id`) references `ombu_tenants`(`id`) on delete cascade
);

-- Circular reference between roles and users
alter table `ombu_roles` add foreign key (`owner`) references `ombu_users`(`id`) on delete cascade;

create table `ombu_extensions` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`name` varchar(255) not null,
	`cos_id` int unsigned default null,
	`call_limit` int unsigned default '0',
	`internal_cid` varchar(255) default null,
	`external_cid` varchar(255) default null,
	`ringtime` int unsigned default null,
	`nospy` enum('yes', 'no') default 'no',
	`enabled_pa` enum('yes', 'no') not null default 'no',
	`answermode` enum('intercom', 'disable') not null default 'disable',
	`call_screen` enum('disable', 'nomemory', 'memory') not null default 'disable',
	`mailbox` varchar(255) default null,
	`accountcode` varchar(25) default null,
	`dialoptions` varchar(255) default null,
	`features_password` varchar(25) default null,
	`photo` varchar(255) default null,
	`sendcid` enum('yes', 'no') default 'yes',
	`generate_hints` enum('yes','no') default 'no',
	`allow_cc` enum('yes','no') default 'no',
	`hot_desking` enum('yes','no') default 'no',
	`secretary` varchar(255) default null,
	`did_number` varchar(255) default null,
	`moh_id` int unsigned default null,
	unique(`extension`),
	primary key (`id`),
	foreign key (`secretary`) references `ombu_extensions` (`extension`) on delete no action on update no action,
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`),
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null
);

create table `ombu_extensions_portal` (
	`ext_portal_id` int unsigned not null auto_increment,
	`extension_id` int unsigned not null,
	`user_id_portal` int unsigned not null,
	`portal_user` varchar(255) not null,
	`enable_portal` enum('yes','no') not null default 'no',
	primary key (`ext_portal_id`),
	unique(`extension_id`),
	unique(`user_id_portal`),
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade,
	foreign key (`user_id_portal`) references `ombu_users` (`id`) on delete cascade
);


create table `ombu_device_profiles` (
	`profile_id` int unsigned not null auto_increment,
	`technology` varchar(255) not null,
	`name` varchar(255) not null,
	`description` varchar(255) default null,
	`default` enum('yes', 'no') default 'no',
	primary key (`profile_id`),
	index (`technology`),
	unique (`name`)
);

create table `ombu_device_profiles_custom` (
	`profile_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`value` varchar(255) not null,
	foreign key (`profile_id`) references `ombu_device_profiles` (`profile_id`) on delete cascade
);

create table `ombu_devices` (
	`id` int unsigned not null auto_increment,
	`extension_id` int unsigned default null,
	`profile` int unsigned not null,
	`user` varchar(255) default null,
	`secret` varchar(255) default null,
	`description` varchar(255) default null,
	`language` varchar(255) not null,
	`ring_device` enum('yes', 'no') not null default 'yes',
	`technology` varchar(255) not null,
	primary key (`id`),
	unique (`user`),
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade,
	foreign key (`profile`) references `ombu_device_profiles` (`profile_id`) on delete restrict
);

create table `ombu_devices_iax` (
	`device_id` int unsigned not null,
	`codecs` varchar(255) default null,
	`deny` varchar(255) default '0.0.0.0/0',
	`permit` varchar(255) default '0.0.0.0/0',
	foreign key (`device_id`) references `ombu_devices`(`id`) on delete cascade
);

create table `ombu_devices_sip` (
	`device_id` int unsigned not null,
	`codecs` varchar(255) default null,
	`dtmfmode` enum('rfc2833', 'info', 'shortinfo', 'inband', 'auto') default 'rfc2833',
	`nat` enum('no', 'force_rport', 'comedia', 'auto_force_rport', 'auto_comedia')default 'no',
	`deny` varchar(255) default '0.0.0.0/0',
	`permit` varchar(255) default '0.0.0.0/0',
	foreign key (`device_id`) references `ombu_devices`(`id`) on delete cascade
);

create table `ombu_followme` (
	`id` int unsigned not null auto_increment,
	`extension_id` int unsigned not null,
	`moh_id` int unsigned default null,
	`followme_numbers` varchar(255) default null,
	`ringtime` int unsigned default null,
	`call_from_prompt` int unsigned default null,
	`pls_hold_prompt` int unsigned default null,
	`status_prompt` int unsigned default null,
	`sorry_prompt` int unsigned default null,
	`norecording_prompt` int unsigned default null,
	`recname` enum('yes','no') default 'no',
	`plshold_status` enum('yes','no') default 'no',
	`playback_unrecheable` enum('yes','no') default 'yes',
	`playback_incoming_status` enum('yes','no') default 'yes',
	primary key (`id`),
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade ,
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null ,
	foreign key (`call_from_prompt`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`pls_hold_prompt`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`status_prompt`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`sorry_prompt`) references `ombu_recordings` (`recording_id`) on delete set null
);

create table `ombu_voicemail_timezones` (
	`id` int unsigned not null auto_increment,
	`tzname` varchar(255) not null,
	`timezone` varchar(255) not null,
	`tzdefinition` varchar(255) not null,
	unique(`tzname`),
	primary key (`id`)
);

create table `ombu_extensions_vm` (
	`extension_id` int unsigned not null,
	`vmtimezone_id` int unsigned default null,
	`password` varchar(25) default null,
	`context` varchar(255) default null,
	`fullname` varchar(255) default null,
	`pager` varchar(255) default null,
	`alias` varchar(255) default null,
	`attachfmt` enum('wav49','wav','gsm') default 'wav49',
	`saycid` enum('yes','no') default 'yes',
	`sayduration` enum('yes','no') default 'yes',
	`envelope` enum('yes','no') default 'yes',
	`delete` enum('yes','no') default 'no',
	`hidefromdir` enum('yes','no') default 'no',
	`enabled` enum('yes','no') default 'no',
	`email` varchar(255) default null,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade ,
	foreign key (`vmtimezone_id`) references `ombu_voicemail_timezones` (`id`) on delete set null
);

create table `ombu_firewall_services` (
	`service_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`protocol` enum('tcp', 'udp', 'both') not null,
	`port` varchar(255) not null,
	primary key(`service_id`),
	unique (`name`)
);

create table `ombu_firewall_rules` (
	`rule_id` int unsigned not null auto_increment,
	`service_id` int unsigned not null,
	`source` varchar(255) not null,
	`destination` varchar(255) not null,
	`action` enum('accept', 'reject', 'drop') not null,
	`index` int unsigned not null,
	primary key(`rule_id`),
	foreign key (`service_id`) references `ombu_firewall_services`(`service_id`) on delete cascade
);

create table `ombu_firewall_whitelist` (
	`whitelist_id` int unsigned not null auto_increment,
	`host` varchar(255) not null,
	`description` varchar(255) default null,
	primary key(`whitelist_id`)
);

create table `ombu_iax_settings` (
	`id` int unsigned not null auto_increment,
	`bindport` int unsigned default null,
	`bindaddr` varchar(255) default null,
	`language` varchar(255) default null,
	`bandwidth` varchar(255) default null,
	`adsi` enum('yes', 'no') default null,
	`srvlookup` enum('yes', 'no') default null,
	`nochecksums` enum('yes', 'no') default null,
	`iaxcompat` enum('yes', 'no') default null,
	`minregexpire` int unsigned default null,
	`maxregexpire` int unsigned default null,
	`iaxthreadcount` int unsigned default null,
	`iaxmaxthreadcount` int unsigned default null,
	`autokill` varchar(255) default null,
	`trunkfreq` int unsigned default null,
	`authdebug` enum('yes', 'no') default null,
	`trunktimestamps` enum('yes', 'no') default null,
	`codecpriority` varchar(255) default null,
	`allowedcodecs` varchar(255) default null,
	`calltokenoptional` varchar(255) default null,
	`maxcallnumbers` varchar(255) default null,
	`maxcallnumbers_nonvalidated` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_iax_number_limits` (
	`iax_settings_id` int unsigned default null,
	`ip` varchar(45) default null,
	`mask` varchar(255) default null,
	`limit` varchar(255) default null,
	`order` int unsigned default null,
	foreign key (`iax_settings_id`) references `ombu_iax_settings` (`id`) on delete cascade
);

create table `ombu_ivr` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`cos_id` int unsigned default null,
	`welcome_msg` int unsigned default null,
	`freedial` enum('yes', 'no') default null,
	`invalid_tries` int unsigned default null,
	`invalid_retry_msg` int unsigned default null,
	`mod_invalid` varchar(255) not null,
	`invalid_dest` varchar(255) not null,
	`invalid_msg` int unsigned default null,
	`invalid_add_msg` enum('yes', 'no') default null,
	`timeout` int unsigned default null,
	`timeout_msg` int unsigned default null,
	`timeout_retry_msg` int unsigned default null,
	`mod_timeout` varchar(255) not null,
	`timeout_dest` varchar(255) not null,
	`timeout_tries` varchar(255) default null,
	`timeout_add_msg` enum('yes', 'no') default null,
	primary key (`id`),
	foreign key (`timeout_retry_msg`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`invalid_retry_msg`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`invalid_msg`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`timeout_msg`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`welcome_msg`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`)
);

create table `ombu_ivr_entries` (
	`ivr_id` int unsigned not null,
	`option` varchar(255) default null,
	`mod_dest` varchar(255) default null,
	`dest` varchar(255) default null,
	`enabled` enum('yes','no') not null,
	`sort` int unsigned not null,
	foreign key (`ivr_id`) references `ombu_ivr` (`id`) on delete cascade
);

create table `ombu_languages` (
	`id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`langcode` varchar(255) not null,
	`description` varchar(255) default null,
	`mod_dest` varchar(255) default null,
	`destination` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_logfiles` (
	`id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`debug` varchar(255) default null,
	`dtmf` varchar(255) default null,
	`error` varchar(255) default null,
	`fax` varchar(255) default null,
	`notice` varchar(255) default null,
	`verbose` varchar(255) default null,
	`warning` varchar(255) default null,
	`security` varchar(255) default null,
	`order` int unsigned not null,
	primary key (`id`),
	unique (`name`)
);

create table `ombu_logfiles_general` (
	`id` int unsigned not null auto_increment,
	`dateformat` varchar(255) default null,
	`queue_log` enum('yes', 'no') default null,
	`rotatestrategy` varchar(255) default null,
	primary key (`id`)
);


create table `ombu_maintenance` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`minutes` varchar(255) not null,
	`hours` varchar(255) not null,
	`days` varchar(255) not null,
	`month` varchar(255) not null,
	`weekday` varchar(255) not null,
	`command` varchar(255) not null,
	`state` enum('yes', 'no') not null,
	primary key (`id`)
);

create table `ombu_masive_voicemail` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`description` varchar(255) default null,
	`password` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_masive_voicemail_extensions` (
	`masive_vm_id` int unsigned not null,
	`extension_id` int unsigned not null,
	foreign key (`masive_vm_id`) references `ombu_masive_voicemail` (`id`) on delete cascade ,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);

create table `ombu_modules` (
	`module_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`displayname` varchar(255) not null,
	`has_dialplan` enum('yes', 'no') not null,
	`admin` enum('yes','no') not null default 'no',
	`version` varchar(255) not null,
	`portal` enum('yes', 'no') default 'no',
	primary key (`module_id`)
);

create table `ombu_settings` (
	`setting_id` int unsigned not null auto_increment,
	`module_id` int unsigned not null,
	`name` varchar(255) not null,
	`value` varchar(255) default null,
	primary key(`setting_id`),
	unique(`module_id`, `name`),
	foreign key (`module_id`) references `ombu_modules` (`module_id`) on delete cascade
);

create table `ombu_main_menu` (
	`id` int unsigned not null auto_increment,
	`label` varchar(255) not null,
	`parent_id` int unsigned default null,
	`module_id` int unsigned default null,
	`font_icon` varchar(255) default null,
	`sort` int unsigned not null,
	primary key (`id`),
	foreign key (`module_id`) references `ombu_modules` (`module_id`) on delete cascade ,
	foreign key (`parent_id`) references `ombu_main_menu` (`id`) on delete cascade
);

create table `ombu_nightmode` (
	`id` int unsigned not null auto_increment,
	`code` int unsigned not null,
	`description` varchar(255) default null,
	`password` varchar(255) default null,
	`mod_dest_normal` varchar(255) default null,
	`normal_dest` varchar(255) default null,
	`mod_dest_override` varchar(255) default null,
	`override_dest` varchar(255) default null,
	primary key (`id`)
);

create table `ombu_paging` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`description` varchar(255) default null,
	`duplex` enum('yes','no') not null default 'no',
	`ignore` enum('yes','no') not null default 'yes',
	`quiet` enum('yes','no') not null default 'yes',
	`record` enum('yes','no') not null default 'no',
	`skip_busy` enum('yes','no') not null default 'yes',
	`timeout` int unsigned not null default '10',
	primary key (`id`),
	unique (`extension`)
);

create table `ombu_paging_extensions` (
	`paging_id` int unsigned not null,
	`extension_id` int unsigned not null,
	foreign key (`paging_id`) references `ombu_paging` (`id`) on delete cascade ,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);

create table `ombu_parking` (
	`id` int unsigned not null auto_increment,
	`extension` int unsigned not null,
	`description` varchar(255) default null,
	`mod_dest` varchar(255) not null,
	`dest` varchar(255) not null,
	`parkingtime` int unsigned not null default 45,
	`comebacktoorigin` enum('yes','no') default 'yes',
	`comebackdialtime` int unsigned not null default 20,
	`parkedplay` varchar(255) default null,
	`parkpos` int unsigned not null default 10,
	`parkedcalltransfers` varchar(255) default null,
	`parkedcallreparking` varchar(255) default null,
	`parkedcallhangup` varchar(255) default null,
	`findslot` varchar(255) default null,
	`moh_id` int unsigned default null,
	`defpark` enum('yes','no') default 'no',
	primary key (`id`),
	unique key `extension` (`extension`),
	key `moh_id` (`moh_id`),
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null
);

create table `ombu_parking_ranges` (
	`parking_id` int unsigned not null,
	`extension` int unsigned not null,
	key `parking_id` (`parking_id`),
	foreign key (`parking_id`) references `ombu_parking` (`id`) on delete cascade
);

create table `ombu_pin` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`passwords` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_preannoun` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`recording` int unsigned default null,
	`mod_dest` varchar(255) not null,
	`destination` varchar(255) not null,
	primary key (`id`),
	foreign key (`recording`) references `ombu_recordings` (`recording_id`) on delete set null
);

create table `ombu_iax_profiles` (
	`profile_id` int unsigned not null,
	`host` varchar(255) not null,
	`peertype` enum('friend', 'peer', 'user') not null,
	`requirecalltoken` enum('yes', 'no', 'auto') not null,
	`qualify` int unsigned not null,
	`qualifyfreq` int unsigned not null,
	`transfer` enum('yes', 'no', 'media') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_device_profiles` (`profile_id`) on delete cascade
);

create table `ombu_sip_profiles` (
	`profile_id` int unsigned not null,
	`host` varchar(255) not null,
	`peertype` enum('friend', 'peer', 'user') not null,
	`qualify` int unsigned not null,
	`qualifyfreq` int unsigned not null,
	`transport` varchar(255) not null,
	`icesupport` enum('yes', 'no') not null,
	`encryption` enum('yes', 'no') not null,
	`avpf` enum('yes', 'no') not null,
	`directmedia` enum('yes', 'no', 'nonat', 'update') not null,
	`sendrpid` enum('yes', 'no', 'rpid', 'pai') not null,
	`trustrpid` enum('yes', 'no') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_device_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_profiles` (
	`profile_id` int unsigned not null auto_increment,
	`signaling` enum(
		'auto', 'fxs_ls', 'fxs_gs', 'fxs_ks', 'fxo_ls', 'fxo_gs', 'fxo_ks',
		'em', 'em_e1', 'em_w', 'featd', 'featdmf', 'featdmf_ta', 'featb', 'fgccama',
		'fgccamamf', 'sf', 'sf_w', 'sf_featd', 'sf_featdmf', 'sf_featb', 'e911', 'ss7',
		'mfcr2', 'bri_cpe', 'bri_net', 'bri_cpe_ptmp', 'bri_net_ptmp', 'pri_net', 'pri_cpe'
	) not null,
	`rxgain` decimal(9,3) not null,
	`txgain` decimal(9,3) not null,
	`echocanceler` enum('none', 'mg2', 'kb1', 'sec', 'sec2', 'hpec', 'hwec', 'oslec') not null,
	`echocancel` enum('32','64','128','256','512') not null,
	`echotraining` int unsigned not null,
	`echocancelwhenbridged` enum('yes', 'no') not null,
	`echoparams` varchar(255) default null,
	`usecallerid` enum('yes', 'no') not null,
	`hidecallerid` enum('yes', 'no') not null,
	`relaxdtmf` enum('yes','no') not null,
	`faxdetect` enum('no', 'incoming', 'outgoing', 'both') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_device_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_analog_profiles` (
	`profile_id` int unsigned not null,
	`answeronpolarityswitch` enum('yes', 'no') not null,
	`hanguponpolarityswitch` enum('yes', 'no') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_dahdi_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_fxs_profiles` (
	`profile_id` int unsigned not null,
	`rxflash` int unsigned not null,
	`threewaycalling` enum('yes', 'no') not null,
	`transfer` enum('yes', 'no') not null,
	`callwaiting` enum('yes', 'no') not null,
	`mwisendtype` varchar(255) not null,
	`callwaitingcallerid` enum('yes', 'no') not null,
	`sendcalleridafter` int unsigned not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_dahdi_analog_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_fxo_profiles` (
	`profile_id` int unsigned not null,
	`cidstart` enum('polarity', 'polarity_IN', 'ring', 'dtmf') not null,
	`cidsignaling` enum('bell', 'v23', 'v23_jp', 'dtmf', 'smdi') not null,
	`dtmfcidlevel` int unsigned not null,
	`polarityonanswerdelay` int unsigned not null,
	`busydetect` enum('yes', 'no') not null,
	`busycount` int unsigned not null,
	`busypattern` varchar(255) default null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_dahdi_analog_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_digital_profiles` (
	`profile_id` int unsigned not null,
	`switchtype` enum('national', 'dms100', '4ess', '5ess', 'euroisdn', 'ni1', 'qsig') not null,
	`inbanddisconnect` enum('yes', 'no') not null,
	`facilityenable` enum('enabled', 'disabled', 'sdn', 'megacom', 'tollfreemegacom', 'accunet') not null,
	`pridialplan` enum('dynamic', 'unknown', 'private', 'local', 'national', 'international') not null,
	`prilocaldialplan` enum('dynamic', 'unknown', 'private', 'local', 'national', 'international') not null,
	`overlapdial` enum('yes', 'no', 'incoming', 'outgoing') not null,
	`resetinterval` int unsigned not null,
	`internationalprefix` varchar(255) default null,
	`nationalprefix` varchar(255) default null,
	`localprefix` varchar(255) default null,
	`privateprefix` varchar(255) default null,
	`unknownprefix` varchar(255) default null,
	`usecallingpres` enum('yes', 'no') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_dahdi_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_r2_profiles` (
	`profile_id` int unsigned not null,
	`variant` enum('ar', 'br', 'mx', 'ph', 'itu', 'cn', 'cz', 'co', 'ec', 'id', 've') not null,
	`maxani` int unsigned not null,
	`maxdnis` int unsigned not null,
	`ani_first` enum('yes', 'no') not null,
	`category` enum(
		'national_subscriber', 'national_priority_subscriber', 'international_subscriber',
		'international_priority_subscriber', 'collect_call'
	) not null,
	`back_timeout` int unsigned not null,
	`pulse_timeout` int unsigned not null,
	`collect_calls` enum('yes', 'no') not null,
	`double_answer` enum('yes', 'no') not null,
	`immediate_accept` enum('yes', 'no') not null,
	`skip_category` enum('yes', 'no') not null,
	`forced_release` enum('yes', 'no') not null,
	`charge_calls` enum('yes', 'no') not null,
	unique (`profile_id`),
	foreign key (`profile_id`) references `ombu_dahdi_digital_profiles` (`profile_id`) on delete cascade
);

create table `ombu_dahdi_channels` (
	`channel_id` int unsigned not null auto_increment,
	`span_id` int unsigned not null,
	`profile_id` int unsigned default null,
	`index` int unsigned not null,
	primary key (`channel_id`),
	unique (`span_id`, `index`),
	foreign key (`span_id`) references `ombu_dahdi_spans` (`span_id`) on delete cascade,
	foreign key (`profile_id`) references `ombu_dahdi_profiles` (`profile_id`) on delete cascade
);

create table `ombu_inbound_route` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`routing_method` enum('default','dahdi') default 'default',
	`did` varchar(255) default null,
	`channel_id` int unsigned default null,
	`overwrite_cid_name` varchar(255) default null,
	`overwrite_cid_number` varchar(255) default null,
	`cid_number` varchar(255) default null,
	`mod_dest` varchar(255) not null,
	`destination` varchar(255) not null,
	`prefix` varchar(255) default null,
	`language` varchar(255) default null,
	`moh_id` int unsigned default null,
	`alertinfo` varchar(255) default null,
	`enablerecording` enum('yes', 'no') default 'no',
	`faxdetection` enum('yes', 'no') default 'no',
	`detectiontime` int unsigned default null,
	`fax_mod_dest` varchar(255) default null,
	`fax_destination` varchar(255) default null,
	`privacyman` enum('yes', 'no') default 'no',
	`pmminlength` int unsigned default 10,
	`pmmaxretries` int unsigned default 3,
	primary key (`id`),
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null,
	foreign key (`channel_id`) references `ombu_dahdi_channels` (`channel_id`) on delete cascade
);

create table `ombu_devices_fxs` (
	`device_id` int unsigned not null,
	`channel_id` int unsigned not null,
	foreign key (`device_id`) references `ombu_devices` (`id`) on delete cascade,
	foreign key (`channel_id`) references `ombu_dahdi_channels` (`channel_id`) on delete cascade
);

create table `ombu_dahdi_channel_caps` (
	`channel_id` int unsigned not null,
	`supports` enum('fxs_ls', 'fxs_gs', 'fxs_ks', 'fxo_ls', 'fxo_gs', 'fxo_ks', 'em', 'clear', 'sf') not null,
	foreign key (`channel_id`) references `ombu_dahdi_channels` (`channel_id`) on delete cascade
);

create table `ombu_dahdi_channel_groups`(
	`group_id` int unsigned not null,
	`channel_id` int unsigned not null,
	unique (`group_id`, `channel_id`),
	foreign key (`group_id`) references `ombu_dahdi_groups`(`group_id`) on delete cascade,
	foreign key (`channel_id`) references `ombu_dahdi_channels` (`channel_id`) on delete cascade
);

create table `ombu_queues_vip` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`list` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_queues` (
	`id` int unsigned not null auto_increment,
	`extension` int unsigned not null,
	`queue_vip_id` int unsigned default null,
	`ivr_id` int unsigned default null,
	`description` varchar(255) default null,
	`mod_dest` varchar(255) default null,
	`destination` varchar(255) default null,
	`strategy` varchar(255) default null,
	`moh_id` int unsigned default null,
	`weight` int unsigned default null,
	`autofill` enum('yes','no') default null,
	`maxlen` int unsigned default null,
	`announce` int unsigned default null,
	`periodic_announce` int unsigned default null,
	`monitor_format` enum('gsm','wav','wav49') default null,
	`servicelevel` int unsigned default null,
	`wrapuptime` int unsigned default null,
	`announce_frequency` varchar(255) default null,
	`min_announce_frequency` varchar(255) default null,
	`periodic_announce_frequency` varchar(255) default null,
	`announce_round_seconds` varchar(255) default null,
	`announce_to_first_user` enum('yes','no') default null,
	`announce_position` varchar(255) default null,
	`announce_position_limit` int unsigned default null,
	`relative_periodic_announce` enum('yes','no') default null,
	`announce_holdtime` enum('yes','no') default null,
	`penaltymemberslimit` int unsigned default null,
	`autopause` varchar(255) default null,
	`ringinuse` enum('yes','no') default null,
	`memberdelay` int unsigned default null,
	`timeoutrestart` enum('yes','no') default null,
	`joinempty` varchar(255) default null,
	`timeoutpriority` varchar(255) default null,
	`timeout` int unsigned default null,
	`queue_timeout` int unsigned default null,
	`leavewhenempty` varchar(255) default null,
	`retry` int unsigned default null,
	primary key (`id`),
	unique (`extension`),
	foreign key (`queue_vip_id`) references `ombu_queues_vip` (`id`) on delete set null ,
	foreign key (`ivr_id`) references `ombu_ivr` (`id`) on delete set null ,
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null ,
	foreign key (`periodic_announce`) references `ombu_recordings` (`recording_id`) on delete set null ,
	foreign key (`announce`) references `ombu_recordings` (`recording_id`) on delete set null
);

create table `ombu_queues_members` (
	`queue_id` int unsigned not null,
	`extension_id` int unsigned not null,
	`type` enum('static','dynamic') not null,
	foreign key (`queue_id`) references `ombu_queues` (`id`) on delete cascade ,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);

create table `ombu_queues_priority` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`mod_dest` varchar(255) default null,
	`destination` varchar(255) default null,
	`priority` int unsigned not null,
	primary key (`id`)
);

create table `ombu_ring_groups` (
	`id` int unsigned not null auto_increment,
	`extension` int unsigned not null,
	`description` varchar(255) default null,
	`strategy` varchar(255) default null,
	`ringtime` int unsigned default null,
	`cos_id` int unsigned default null,
	`moh_id` int unsigned default null,
	`prefix` varchar(255) default null,
	`mod_dest` varchar(255) not null,
	`destination` varchar(255) not null,
	primary key (`id`),
	unique (`extension`),
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null,
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`) on delete restrict
);

create table `ombu_ring_groups_extensions` (
	`ring_group_id` int unsigned not null,
	`extension_id` int unsigned not null,
	foreign key (`ring_group_id`) references `ombu_ring_groups` (`id`) on delete cascade ,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);


create table `ombu_roles_privileges` (
	`role_id` int unsigned not null,
	`module_id` int unsigned not null,
	`allow_view` enum('yes','no') not null,
	`allow_add` enum('yes','no') not null,
	`allow_edit` enum('yes','no') not null,
	`allow_delete` enum('yes','no') not null,
	unique (`role_id`,`module_id`),
	foreign key (`role_id`) references `ombu_roles` (`id`) on delete cascade ,
	foreign key (`module_id`) references `ombu_modules` (`module_id`) on delete cascade
);

create table `ombu_sip_settings` (
	`id` int unsigned not null auto_increment,
	`language` varchar(255) default null,
	`tonezone` varchar(255) default null,
	`dtmfmode` varchar(255) default null,
	`bindaddr` varchar(255) default null,
	`bindport` int unsigned default null,
	`maxcallbitrate` int unsigned default null,
	`maxexpiry` int unsigned default null,
	`minexpiry` int unsigned default null,
	`defaultexpiry` int unsigned default null,
	`mwiexpiry` int unsigned default null,
	`nat` varchar(255) default null,
	`externaddr` varchar(255) default null,
	`externhost` varchar(255) default null,
	`externrefresh` varchar(255) default null,
	`qualifyfreq` int unsigned default null,
	`rtptimeout` int unsigned default null,
	`rtpholdtimeout` int unsigned default null,
	`jbenabled` enum('yes', 'no') default null,
	`jbforce` enum('yes', 'no') default null,
	`jbmaxsize` int unsigned default null,
	`jbresyncthreshold` int unsigned default null,
	`jbimpl` varchar(255) default null,
	`jbtargetextra` int unsigned default null,
	`allowedcodecs` varchar(45) default null,
	`callcounter` enum('yes', 'no') default null,
	`allowtransfer` enum('yes', 'no') default null,
	`g726nonstandard` enum('yes', 'no') default null,
	`notifyringing` enum('yes', 'no') default null,
	`notifyhold` enum('yes', 'no') default null,
	`notifycid` enum('yes', 'no') default null,
	`videosupport` enum('yes', 'no') default null,
	`faxdetect` enum('yes', 'no') default null,
	`t38pt_udptl` enum('yes', 'no') default null,
	`allowguest` enum('yes', 'no') default null,
	`authfailureevents` enum('yes', 'no') default null,
	`alwaysauthreject` enum('yes', 'no') default null,
	`accept_outofcall_message` enum('yes', 'no') default null,
	`dynamic_exclude_static` enum('yes', 'no') default null,
	`preferred_codec_only` enum('yes', 'no') default null,
	`autoframing` enum('yes', 'no') default null,
	`srvlookup` enum('yes', 'no') default null,
	`sipdebug` enum('yes', 'no') default null,
	`recordhistory` enum('yes', 'no') default null,
	`dumphistory` enum('yes', 'no') default null,
	`tos_sip` varchar(255) not null,
	`tos_audio` varchar(255) not null,
	`tos_video` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_sip_custom_settings` (
	`sip_settings_id` int unsigned default null,
	`param` varchar(255) default null,
	`value` varchar(255) default null,
	index (`sip_settings_id`),
	foreign key (`sip_settings_id`) references `ombu_sip_settings` (`id`) on delete cascade
);

create table `ombu_sip_local_network` (
	`sip_settings_id` int unsigned default null,
	`ip` varchar(255) default null,
	`netmask` varchar(255) default null,
	index (`sip_settings_id`),
	foreign key (`sip_settings_id`) references `ombu_sip_settings` (`id`) on delete cascade
);

create table `ombu_speed_dial` (
	`id` int unsigned not null auto_increment,
	`extension` varchar(255) not null,
	`description` varchar(255) default null,
	`cos_id` int unsigned default null,
	`dnumber` varchar(255) not null,
	primary key (`id`),
	unique (`extension`),
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`) on delete set null
);

create table `ombu_system` (
	`id` int unsigned not null auto_increment,
	`mod` varchar(255) not null,
	`name` varchar(255) not null,
	`order` int unsigned not null,
	`visible` int unsigned not null,
	primary key (`id`)
);

create table `ombu_system_misc` (
	`section` varchar(255) default null,
	`parameter` varchar(255) not null,
	`value` varchar(255)
);

create table `ombu_system_settings` (
	`id` int unsigned not null auto_increment,
	`mod_id` int unsigned not null,
	`param` varchar(255) not null,
	`label` varchar(255) default null,
	`value` varchar(255) default null,
	`type` varchar(255) default null,
	`options` varchar(255) default null,
	`readonly` int unsigned not null,
	`empty` int unsigned not null,
	`help` varchar(255) default null,
	`order` int unsigned not null,
	`generate` enum('yes','no') not null default 'yes',
	primary key (`id`),
	foreign key (`mod_id`) references `ombu_system` (`id`) on delete cascade
);

create table `ombu_tenants_trunks` (
	`id` int unsigned not null auto_increment,
	`tenant_id` int unsigned not null,
	`trunk` varchar(255) not null,
	primary key (`id`),
	foreign key (`tenant_id`) references `ombu_tenants` (`id`) on delete cascade
);

create table `ombu_time_groups` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`extension` varchar(255) not null,
	primary key (`id`)
);

create table `ombu_time_conditions` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`time_group_id` int unsigned not null,
	`modtrue` varchar(255) not null,
	`truegoto` varchar(255) not null,
	`modfalse` varchar(255) not null,
	`falsegoto` varchar(255) not null,
	primary key (`id`),
	foreign key (`time_group_id`) references `ombu_time_groups` (`id`)
);

create table `ombu_time_groups_schedules` (
	`time_group_id` int unsigned not null,
	`time` varchar(255) not null,
	`sort` int unsigned not null,
	`tcini` varchar(255) not null,
	`tcend` varchar(255) not null,
	index (`time_group_id`),
	foreign key (`time_group_id`) references `ombu_time_groups` (`id`) on delete cascade
);

create table `ombu_trunks` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`technology` varchar(255) not null,
	`cos_id` int unsigned default null,
	`dialoptions` varchar(255) default null,
	`ringtimer` int unsigned default null,
	`moh_id` int unsigned default null,
	`register` varchar(255) default null,
	`dialstring` varchar(255) default null,
	`trunk_cid` varchar(255) default null,
	`overwrite_cid` enum('yes','no') default 'no',
	`group_id` int unsigned default null,
	`group_mode` enum('g','G','r','R') not null collate ascii_bin,
	`outgoing_username` varchar(255) default null,
	`incoming_username` varchar(255) default null,
	primary key (`id`),
	foreign key (`moh_id`) references `ombu_music_groups` (`group_id`) on delete set null,
	foreign key (`cos_id`) references `ombu_class_of_service` (`id`) on delete set null,
	foreign key (`group_id`) references `ombu_dahdi_groups` (`group_id`) on delete cascade
);

create table `ombu_trunks_parameters` (
	`trunks_id` int unsigned default null,
	`advanced_param` enum('yes', 'no') default 'yes',
	`type` enum('friend', 'user', 'peer') default null,
	`param` varchar(255) not null,
	`value` varchar(255) default null,
	`enabled` enum('yes', 'no') default 'yes',
	`sort` int unsigned default 0,
	index (`trunks_id`),
	foreign key (`trunks_id`) references `ombu_trunks` (`id`) on delete cascade
);

create table `ombu_trunks_group` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`tenant_trunk` varchar(255) default null,
	`pin_id` int unsigned default null,
	primary key (`id`),
	foreign key (`pin_id`) references `ombu_pin` (`id`)
);

create table `ombu_ars_members` (
	`ars_id` int unsigned not null,
	`trkgroup_id` int unsigned not null,
	`time_group_id` int unsigned default null,
	`enabled` enum('yes','no') not null,
	`sort` int unsigned not null,
	foreign key (`ars_id`) references `ombu_ars` (`id`) on delete cascade ,
	foreign key (`trkgroup_id`) references `ombu_trunks_group` (`id`),
	foreign key (`time_group_id`) references `ombu_time_groups` (`id`)
);

create table `ombu_trunks_group_items` (
	`trkgroup_id` int unsigned not null,
	`trunk_id` int unsigned not null,
	`index` int unsigned not null,
	foreign key (`trkgroup_id`) references `ombu_trunks_group` (`id`) on delete cascade ,
	foreign key (`trunk_id`) references `ombu_trunks` (`id`)
);

create table `ombu_trunks_group_ivirtuals` (
	`trkgroup_id` int unsigned not null,
	`tenant_id` int unsigned not null,
	key `trkgroup_id` (`trkgroup_id`),
	key `trunk_id` (`tenant_id`),
	foreign key (`trkgroup_id`) references `ombu_trunks_group` (`id`) on delete cascade
);

create table `ombu_trunks_group_patterns` (
	`trkgroup_id` int unsigned not null,
	`prepend` varchar(255) default null,
	`prefix` varchar(255) default null,
	`pattern` varchar(255) not null,
	`order` int unsigned not null,
	foreign key (`trkgroup_id`) references `ombu_trunks_group` (`id`) on delete cascade
);

create table `ombu_sessions` (
	`session_id` binary(20) not null,
	`user_id` int unsigned not null,
	`created` timestamp not null default current_timestamp,
	`modified` timestamp null default null,
	primary key(`session_id`),
	index(`modified`),
	foreign key (`user_id`) references `ombu_users` (`id`) on delete cascade
);

create table `ombu_voicemail_conf` (
	`id` int unsigned not null auto_increment,
	`format` varchar(255) default null,
	`maxsecs` int unsigned default null,
	`minsecs` int unsigned default null,
	`maxgreet` int unsigned default null,
	`maxsilence` int unsigned default null,
	`maxlogins` int unsigned default null,
	`moveheard` enum('yes', 'no') default null,
	`backupdeleted` int unsigned default null,
	`forcename` enum('yes', 'no') default null,
	`usedirectory` enum('yes', 'no') default null,
	`operator` enum('yes', 'no') default null,
	`review` enum('yes', 'no') default null,
	`searchcontexts` enum('yes', 'no') default null,
	`serveremail` varchar(255) default null,
	`attach` enum('yes', 'no') default 'no',
	`emailsubject` varchar(255) default null,
	`emailbody` text default null,
	primary key (`id`)
);

create table `ombu_wake_up_call` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`filename` varchar(255) default null,
	`destination` varchar(255) default null,
	`date` date default null,
	`time` time default null,
	`cos` int unsigned default null,
	`cidname` varchar(255) default null,
	`retrytime` varchar(255) default null,
	`maxretries` varchar(255) default null,
	`ringtime` varchar(255) default null,
	primary key (`id`),
	foreign key (`cos`) references `ombu_class_of_service` (`id`) on delete restrict
);

create table `ombu_xml_directory` (
	`id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	`description` varchar(255) default null,
	`server` varchar(255) not null,
	`dbuser` varchar(255) not null,
	`dbpass` varchar(255) default null,
	`database` varchar(255) not null,
	`prefix` varchar(255) default null,
	`guide` varchar(255) default null,
	`gdext` enum('yes', 'no') default null,
	`gdringroup` enum('yes', 'no') default null,
	`gdqueue` enum('yes', 'no') default null,
	`yealink` enum('yes', 'no') default null,
	`grandstream` enum('yes', 'no') default null,
	`cctel` enum('yes', 'no') default null,
	primary key (`id`)
);

create table `ombu_asterisk_manager_users` (
	`id` int unsigned not null auto_increment,
	`user_name` varchar(255) not null,
	`description` varchar(255) not null,
	`secret` varchar(255) not null,
	`deny` varchar(255) not null,
	`permit` varchar(255) not null,
	`read` varchar(255) default null,
	`write` varchar(255) default null,
	unique(`user_name`),
	primary key(`id`)
);

create table `ombu_cdr_filters` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`order_by` varchar(255) default null,
	`order` enum('asc','desc') default 'asc',
	primary key(`id`)
);

create table `ombu_filter_conditions` (
	`filter_id` int unsigned default null,
	`condition` enum('or','and') default null,
	`search_by` varchar(255) default null,
	`value` varchar(255) default null,
	`exclude` enum('yes','no') default null,
	`mode` varchar(255) default null,
	foreign key (`filter_id`) references `ombu_cdr_filters` (`id`) on delete cascade
);

create table `ombu_reload` (
	`reload_configurations` enum('yes','no') not null default 'no',
	`reload_dpma` enum('yes','no') not null default 'no'
);

create table `ombu_syssettings_dhcp_leases` (
	`lease_id` int unsigned not null auto_increment,
	`mac` varchar(255) not null,
	`ip` varchar(255) not null,
	`host` varchar(255) not null,
	primary key (`lease_id`),
	unique key `mac` (`mac`)
);

create table `ombu_contact_book` (
	`contact_id` int unsigned not null auto_increment,
	`extension_id` int unsigned default null,
	`prefix` varchar(255) default null,
	`first_name` varchar(255) default null,
	`number` varchar(255) default null,
	`second_name` varchar(255) default null,
	`last_name` varchar(255) default null,
	`suffix` varchar(255) default null,
	`contact_type` enum('sip','special') not null default 'sip',
	`organization` varchar(255) default null,
	`job_title` varchar(255) default null,
	`location` varchar(255) default null,
	`notes` varchar(255) default null,
	`account_id` varchar(255) default null,
	`subscribe_to` varchar(255) default null,
	`email` varchar(255) default null,
	primary key (`contact_id`),
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);

create table `ombu_dpma_phone_book` (
	`phone_book_id` int unsigned not null auto_increment,
	`group_name` varchar(255) not null,
	primary key (`phone_book_id`),
	unique key `group_name` (`group_name`)
);

create table `ombu_dpma_phone_book_contacts` (
	`phone_book_id` int unsigned not null,
	`contact_id` int unsigned not null,
	`sort` int unsigned not null,
	foreign key (`phone_book_id`) references `ombu_dpma_phone_book` (`phone_book_id`) on delete cascade,
	foreign key (`contact_id`) references `ombu_contact_book` (`contact_id`) on delete cascade
);

create table `ombu_dpma_smart_blf` (
	`id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	`phone_model_id` int unsigned default null,
	`phone_book_id` int unsigned default null,
	primary key (`id`),
	foreign key (`phone_model_id`) references `digium_phone_models` (`phone_model_id`) on delete restrict on update no action,
	foreign key (`phone_book_id`) references `ombu_dpma_phone_book` (`phone_book_id`) on delete restrict on update no action
);

create table `ombu_dpma_smart_blf_items` (
	`smart_blf_id` int unsigned not null,
	`page` int unsigned default null,
	`key` int unsigned not null,
	`contact_id` int unsigned default null,
	foreign key (`smart_blf_id`) references `ombu_dpma_smart_blf` (`id`) on delete cascade,
	foreign key (`contact_id`) references `ombu_contact_book` (`contact_id`) on delete SET null on update no action
);

create table `ombu_dpma_phones_profiles` (
	`phone_profile_id` int unsigned not null auto_increment,
	`description` varchar(255) not null,
	`ntp_resync` int unsigned default null,
	`ehs` enum('auto','plantronics','jabra_id') not null default 'auto',
	`timezone` varchar(255) not null,
	`accept_local_calls` enum('any','host') not null default 'any',
	`lan_port_mode` enum('auto','10hd','10fd','100hd','100fd','1000fd','off') not null default 'auto',
	`pc_port_mode` enum('auto','10hd','10fd','100hd','100fd','1000fd','off') not null default 'auto',
	`ringer_volume` int unsigned not null default '5',
	`speaker_volume` int unsigned not null default '5',
	`handset_volume` int unsigned not null default '5',
	`headset_volume` int unsigned not null default '5',
	`handset_sidetone_db` int not null default -25,
	`headset_sidetone_db` int not null default -15,
	`call_waiting_tone` enum('yes','no') not null default 'no',
	`reset_call_volume` enum('yes','no') not null default 'no',
	`headset_answer` enum('yes','no') not null default 'no',
	`display_mc_notification` enum('yes','no') not null default 'yes',
	`default_fontsize` int unsigned not null default '10',
	`brightness` int unsigned not null default '5',
	`contrast` int unsigned not null default '5',
	`dim_backlight` enum('yes','no') not null default 'yes',
	`backlight_timeout` int unsigned not null default '0',
	`backlight_dim_level` int unsigned not null default '2',
	`logo` varchar(255) default null,
	`default` enum('yes','no') default 'no',
	primary key (`phone_profile_id`)
);

create table `ombu_dpma_phones` (
	`id` int unsigned not null auto_increment,
	`phone_model_id` int unsigned not null,
	`phone_profile_id` int unsigned not null,
	`full_name` varchar(255) not null,
	`phone_book_blf_id` int unsigned default null,
	`mac` varchar(255) default null,
	`contacts_max_subscriptions` int unsigned not null default '50',
	`parking_exten` int unsigned default null,
	`parking_transfer_type` enum('blind','attended') default null,
	`show_call_parking` enum('yes','no') not null default 'no',
	`web_ui_enabled` enum('yes','no') not null default 'no',
	`record_own_calls` enum('yes','no') not null default 'no',
	`can_forward_calls` enum('yes','no') not null default 'no',
	`show_call_log` enum('yes','no') not null default 'no',
	`use_local_storage` enum('yes','no') not null default 'no',
	`send_to_vm` enum('yes','no') not null default 'yes',
	`blf_unused_linekeys` enum('yes','no') not null default 'no',
	`enable_check_sync` enum('yes','no') not null default 'yes',
	`pin` int unsigned default null,
	`group_pin` int unsigned default null,
	`lock_preferences` enum('yes','no') not null default 'no',
	`login_password` varchar(255) default null,
	`active_locale` varchar(255) not null default 'en_US',
	`use_default_ringtones` enum('yes','no') not null default 'yes',
	`digium_ringtone` varchar(255) default 'Digium',
	`ringtone_id` int unsigned default null,
	primary key (`id`),
	foreign key (`phone_book_blf_id`) references `ombu_dpma_smart_blf` (`id`) on delete restrict,
	foreign key (`phone_model_id`) references `digium_phone_models` (`phone_model_id`) on delete restrict,
	foreign key (`phone_profile_id`) references `ombu_dpma_phones_profiles` (`phone_profile_id`) on delete restrict,
	foreign key (`parking_exten`) references `ombu_parking` (`id`) on delete restrict,
	foreign key (`ringtone_id`) references `ombu_dpma_ringtones` (`id`) on delete restrict
);

create table `ombu_dpma_extlines` (
	`id` int unsigned not null auto_increment,
	`userid` varchar(255) not null,
	`authname` varchar(255) default null,
	`line_label` varchar(255) default null,
	`secret` varchar(255) not null,
	`callerid` varchar(255) default null,
	`register` enum('yes','no') not null,
	`server_address` varchar(255) not null,
	`server_port` int unsigned not null,
	`transport` enum('tcp','udp') not null,
	`secondary_server_address` varchar(255) default null,
	`secondary_server_port` int unsigned default null,
	`secondary_server_transport` enum('tcp','udp') default null,
	primary key (`id`)
);

create table `ombu_dpma_firmwares` (
	`id` int unsigned not null auto_increment,
	`file` varchar(255) not null,
	`description` varchar(255) default null,
	`phone_model_id` int unsigned not null,
	`version` varchar(255) not null,
	`public_firmware` enum('yes','no') not null,
	primary key (`id`),
	foreign key (`phone_model_id`) references `digium_phone_models` (`phone_model_id`) on delete cascade
);

create table `ombu_dpma_phones_alerts` (
	`phone_id` int unsigned not null,
	`alert_id` int unsigned not null,
	foreign key (`alert_id`) references `ombu_dpma_alerts` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_applications` (
	`phone_id` int unsigned not null,
	`application_id` int unsigned not null,
	foreign key (`application_id`) references `ombu_dpma_app` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_external_lines` (
	`phone_id` int unsigned not null,
	`external_line_id` int unsigned not null,
	foreign key (`external_line_id`) references `ombu_dpma_extlines` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_firmwares` (
	`phone_id` int unsigned not null,
	`firmware_id` int unsigned not null,
	foreign key (`firmware_id`) references `ombu_dpma_firmwares` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_lines` (
	`phone_id` int unsigned not null,
	`device_id` int unsigned not null,
	`voicemail_uri` varchar(255) default null,
	`digit_map` varchar(255) default null,
	foreign key (`device_id`) references `ombu_devices` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_networks` (
	`phone_id` int unsigned not null,
	`network_id` int unsigned not null,
	foreign key (`network_id`) references `ombu_dpma_networks` (`id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_dpma_phones_phone_books` (
	`phone_id` int unsigned not null,
	`phone_book_id` int unsigned not null,
	foreign key (`phone_book_id`) references `ombu_dpma_phone_book` (`phone_book_id`) on delete cascade,
	foreign key (`phone_id`) references `ombu_dpma_phones` (`id`) on delete cascade
);

create table `ombu_pickup_group` (
	`pickup_id` int unsigned not null auto_increment,
	`description` varchar(255) default null,
	primary key (`pickup_id`)
);

create table `ombu_pickup_group_extensions` (
	`pickup_id` int unsigned not null,
	`extension_id` int unsigned not null,
	`allow_pickup` enum('yes','no') not null default 'no',
	`group_member` enum('yes','no') not null default 'yes',
	foreign key (`pickup_id`) references `ombu_pickup_group` (`pickup_id`) on delete cascade,
	foreign key (`extension_id`) references `ombu_extensions` (`id`) on delete cascade
);
