-- add profile column and change default for codecs

alter table `ombutel`.`ombu_sip_trunks`
	add column `profile_id` int unsigned default null after `trunk_id`,
	modify column `codecs` varchar(255) default null,
	add foreign key (`profile_id`) references `ombutel`.`ombu_sip_profiles` (`profile_id`) on delete cascade;

-- use default profile for regular trunks

update `ombutel`.`ombu_sip_trunks` st
left join `ombutel`.`ombu_device_profiles` dp on (dp.`technology` = 'sip' and dp.`default` = 'yes')
left join `ombutel`.`ombu_sip_profiles` sp on (sp.`profile_id` = dp.`profile_id`)
set st.`profile_id` = sp.`profile_id`, st.`codecs` = ''
where st.`codecs` = sp.`codecs`
and st.`autoframing` = sp.`autoframing`
and st.`videosupport` = sp.`videosupport`
and st.`maxcallbitrate` = sp.`maxcallbitrate`
and st.`preferred_codec_only` = sp.`preferred_codec_only`;

-- generate profiles for customized trunks

insert into `ombutel`.`ombu_device_profiles` (`technology`, `name`, `default`)
select 'sip', concat('SIP Trunk Profile - ',t.`description`), 'no'
from `ombutel`.`ombu_sip_trunks` st
left join `ombutel`.`ombu_trunks` t on (t.`trunk_id` = st.`trunk_id`)
left join `ombutel`.`ombu_device_profiles` dp on (dp.`technology` = 'sip' and dp.`default` = 'yes')
left join `ombutel`.`ombu_sip_profiles` sp on (sp.`profile_id` = dp.`profile_id`)
where st.`profile_id` is null
order by st.`trunk_id`;

set @first_profile_id := last_insert_id();
set @profile_id := greatest(@first_profile_id, 1) - 1;

insert into `ombutel`.`ombu_sip_profiles` (`profile_id`, `codecs`, `autoframing`,
	`videosupport`, `maxcallbitrate`, `host`, `qualify`, `peertype`,
	`qualifyfreq`, `transport`, `preferred_codec_only`, `icesupport`,
	`encryption`, `avpf`, `directmedia`, `sendrpid`, `trustrpid`)
select @profile_id := @profile_id + 1, `codecs`, `autoframing`,
	`videosupport`, `maxcallbitrate`, '', 3600, 'friend',
	60, 'udp', `preferred_codec_only`, 'no',
	'no', 'no', 'nonat', 'yes', 'yes'
from `ombutel`.`ombu_sip_trunks`
where `profile_id` is null
order by `trunk_id`;

set @profile_id := greatest(@first_profile_id, 1) - 1;

update `ombutel`.`ombu_sip_trunks`
set `profile_id` = (@profile_id := @profile_id + 1)
where `profile_id` is null
order by `trunk_id`;

-- remove obsolete columns

alter table `ombutel`.`ombu_sip_trunks`
	drop column `autoframing`,
	drop column `videosupport`,
	drop column `maxcallbitrate`,
	drop column `preferred_codec_only`;
