-- make timezones per-model

create table `ombutel`.`xepm_model_timezones` (
	`model_id` int unsigned not null,
	`timezone_id` int unsigned not null,
	unique key `model_timezone` (`model_id`, `timezone_id`),
	constraint `model` foreign key (`model_id`)
	references `ombutel`.`xepm_models`(`model_id`) on delete cascade,
	constraint `timezone` foreign key (`timezone_id`)
	references `ombutel`.`xepm_timezones`(`timezone_id`) on delete cascade
) charset=utf8 collate=utf8_unicode_ci;

insert into `ombutel`.`xepm_model_timezones` (`model_id`, `timezone_id`)
select m.`model_id`, t.`timezone_id`
from `ombutel`.`xepm_timezones` t
left join `ombutel`.`xepm_models` m using (`brand_id`);

alter table `ombutel`.`xepm_timezones`
	drop foreign key `xepm_timezones_ibfk_1`,
	drop key `brand_id`,
	drop column `brand_id`;

-- deduplicate timezones

update `ombutel`.`xepm_timezones` set
	`name` = trim(replace(replace(replace(`name`, char(9),''),char(10),''),char(13),'')),
	`value` = trim(replace(replace(replace(`value`, char(9),''),char(10),''),char(13),''));

create temporary table `ombutel`.`unique_timezones` (
	`timezone_id` int unsigned not null,
	`offset` int not null,
	`name` varchar(255) not null,
	`value` varchar(255) not null,
	unique key(`offset`, `name`, `value`)
) charset=utf8 collate=utf8_unicode_ci;

insert ignore into `ombutel`.`unique_timezones` (`timezone_id`, `offset`, `name`, `value`)
select `timezone_id`, `offset`, `name`, `value`
from `ombutel`.`xepm_timezones`
order by timezone_id;

update `ombutel`.`xepm_model_timezones` mt
left join `ombutel`.`xepm_timezones` tz using (`timezone_id`)
left join `ombutel`.`unique_timezones` ut on
	(ut.`offset` = tz.`offset` and ut.`name` = tz.`name` and ut.`value` = tz.`value`)
set mt.`timezone_id` = ut.`timezone_id`;

delete from `ombutel`.`xepm_timezones`
where `timezone_id` not in (select `timezone_id` from `ombutel`.`unique_timezones`);
