
function xepm() {
	this.url = './';
	this.template_load = false; // preventing redundant ajax calls on template selection
}

// Assign events to page elements
xepm.prototype.assign_events = function() {
	$("#epm_templategeneral select").bind("change keyup", function(event) {
		xepm.handle_dropdown(event);
	});
};

// Process dropdown event
xepm.prototype.handle_dropdown = function(event) {
	var element = event.target;
	if (element.previous_value != element.value) {
		element.previous_value = element.value;
		xepm.template_load = false;
		switch (element.name) {
			case "brand_id": {
				xepm.clean_all_data();
				xepm.populate_on_brand_selection(element.value); break;
			}
			case "model_id": {
				xepm.clean_all_data();
				xepm.populate_on_model_selection(); break;
			}
			case "conf_id": {
				xepm.clean_all_data();
				xepm.populate_on_configuration_type_selection(); break;
			}
		}
	}
};

// Fill dropdown with JSON data
jQuery.fn.fill = function(data, callback, prepend) {
	var element = this;
	element.empty();
	if (prepend) {
		var option = $("<option/>");
		option.val(prepend[0]);
		option.text(prepend[1]);
		element.append(option);
	}
	if (data) {
		$.each(data, function() {
			var option = $("<option/>");
			callback.apply(option, [ this ]);
			element.append(option);
		});
	}
	element.prop("selectedIndex", 0).trigger("fill");
};

// Populate models, types and timezone dropdowns on brand selection
xepm.prototype.populate_on_brand_selection = function(brand_id) {
	var promise = $.ajax({
		type: "POST",
		url: xepm.url,
		dataType: 'json',
		data: {
			class: 'endpoint',
			method: 'models',
			brand_id: brand_id
		}
	});
	promise.then(function (data) {
		[
			xepm.populate_models(data),
			xepm.populate_on_model_selection(),
			xepm.populate_host_settings()
		]
	});
};

xepm.prototype.populate_model = function(data) {
	var models_dropdown = $("select[name='model_id']");
	var p = $('#epm_templategeneral p.epm_model_name');
	if(!p.length) {
		p = $("<p>", {"class": "form-control-static epm_model_name"});
	}
	p.html("<b>" + data.model.name + "</b>");
	models_dropdown.hide().parent().append(p);
	xepm.populate_models({ "models" : [ data.model ] });
	xepm.populate_timezones(data);
}

// Populates models dropdown field
xepm.prototype.populate_models = function(data) {
	var models_dropdown = $("select[name='model_id']");
	models_dropdown.fill(data.models, function(model) {
		this.val(model.model_id);
		this.text(model.name);
	});
};

// Populate timezones dropdown field
xepm.prototype.populate_timezones = function(data) {
	$("select[name='timezone_id']").fill(data.timezones, function(timezone) {
		this.val(timezone.timezone_id);
		if (timezone.timezone_id == '') {
			this.text(timezone.name);
		} else {
			this.text(timezone.display_offset + ' ' + timezone.name);
		}
	}, ['', data.auto_timezone]);
};

// Populate configuration types, button lines and button types
xepm.prototype.populate_on_model_selection = function() {
	var model_id = $("select[name='model_id']").val();
	delete xepm.visible_module;
	delete xepm.attached_modules;
	var promise = $.ajax({
		type: "POST",
		url: xepm.url,
		dataType: 'json',
		data: {
			class: 'endpoint',
			method: 'model_data',
			model_id: model_id
		}
	});
	promise.then(function (data) {
		[
			xepm.populate_configuration_types(data),
			xepm.populate_on_configuration_type_selection(),
			xepm.populate_model_button_data(data.model_button_types, data.lines),
			xepm.populate_module_button_data(data.module_button_types, data.lines),
			xepm.populate_timezones(data),
		]
	});
};

xepm.prototype.populate_host_settings = function() {
	$("select[name='host_id']").val($("select[name='host_id'] option:eq(0)").val());
};

xepm.prototype.populate_configuration_type = function(data) {
	var configuration_select = $("select[name='conf_id']");
	var p = $('#epm_templategeneral p.configuration_name');
	if(!p.length) {
		p = $("<p>", {"class": "form-control-static configuration_name"});
	}
	p.html("<b>" + data.configuration_type + "</b>");
	configuration_select.hide().parent().append(p);
	xepm.populate_configuration_types({
		"configurations" : [
			{
				"configuration_type_id" : data.configuration_type_id,
				"name" : data.configuration_type
			}
		]
	});
}

// Populate configuration types
xepm.prototype.populate_configuration_types = function(data) {
	var configuration_select = $("select[name='conf_id']");
	configuration_select.fill(data.configurations, function(conf) {
		this.val(conf.configuration_type_id);
		this.text(conf.name);
	});
};

// Populate device buttons, expansion module and advanced setting tabs on brand selection
xepm.prototype.populate_on_configuration_type_selection = function() {
	var configuration_type_id = $("select[name='conf_id']").val();
	if(parseInt(configuration_type_id) > 0) {
		var promise = $.ajax({
			type: "POST",
			url: xepm.url,
			dataType: 'json',
			data: {
				class: 'endpoint',
				method: 'model_settings_and_buttons',
				edit_template: xepm.template_load,
				configuration_type_id: configuration_type_id
			}
		});
		promise.then(function(data) {
			$('p.epm_select_model').css({'display':'none'});
			if(!xepm.template_load && !xepm.populate_device_buttons(data.device_buttons)) {
				$('p.epm_no_buttons').css({'display':'block'}); // no device buttons
			} else {
				$('p.epm_no_buttons').css({'display':'none'});
			}
		});
		promise.then(function(data) {
			if(!xepm.template_load) {
				[
					xepm.populate_setting_groups(data.advanced_settings),
					xepm.populate_advanced_settings(data.advanced_settings)
				],
				$("div.setting_group").first().show(); // show advanced settings
			}
		});
		promise.then(function(data) {
			if(!xepm.template_load) {
				[ xepm.populate_expansion_modules(data) ]
			}
		});
	}
};

// Populate max expansion modules and dropdown field for new template
xepm.prototype.populate_expansion_modules = function(data) {
	if(typeof data.expansion_modules !== 'undefined' && $(data.expansion_modules).length > 0) {
		$('#epm_templateexp_module #max_modules').val(data.max_modules);
		$('#epm_templateexp_module select#module_id').fill(data.expansion_modules, function(module) {
			this.val(module.module_id);
			this.text(module.name);
		});
		$('div#epm_templateexp_module .epm_exp_module').css({'display':'block'}); // Unhide exp. modules drop down
		xepm.show_exp_not_supported(false);
	} else { // no exp buttons
		xepm.show_exp_not_supported(true);
	}
}

// Populate device buttons
xepm.prototype.populate_device_buttons = function(buttons) {
	if(buttons != null && (
		typeof buttons.dss !== 'undefined' && $(buttons.dss).length ||
		typeof buttons.line !== 'undefined' && $(buttons.line).length)) {
		if($(buttons.dss).length) { // DSS buttons
			var row = $("table.device_buttons").find('tr.device_buttons_row');
			var button_type = 'device_buttons'; // table name
			$.each(buttons.dss, function(index, button) {
				var button_row = row.clone();
				button_row = xepm.add_device_buttons(button_row, index, button, button_type);
				$(button_row).appendTo($('table.device_buttons tbody'));
			});
			$('div#epm_templatedevice_buttons table.device_buttons').css({'display':'block'});
			$('div.epm_template_dss').css({'display':'block'});
		}
		if($(buttons.line).length) { // Line buttons
			var row = $("table.device_buttons").find('tr.device_buttons_line_row');
			var button_type = 'device_buttons_line'; // table name
			$.each(buttons.line, function(index, button) {
				var button_row = row.clone();
				button_row = xepm.add_device_buttons(button_row, index, button, button_type);
				$(button_row).appendTo($('table.device_buttons_line tbody'));
			});
			$('div#epm_templatedevice_buttons table.device_buttons_line').css({'display':'block'});
			$('div.epm_template_line').css({'display':'block'});
		}
		return true;
	}
	return false;
};

// Populate advance settings groups dropdown field
xepm.prototype.populate_setting_groups = function(settings) {
	var div = $('div#epm_templateadv_settings div.epm_advanced_settings');
	$.each(settings, function(index, group) {
		if($(group).attr('children') && group.children.length > 0) {
			div.find('select').append($('<option/>').val(group.setting_id).text(group.name));
			xepm.populate_setting_groups(group.children);
		}
	});
	div.css({'display' : 'block'});
};

// Populate advance settings
xepm.prototype.populate_advanced_settings = function(settings) {
	var fragment = document.createDocumentFragment();
	var sub_groups = [];

	settings.forEach(function(group) {
		// Check if group already exists
		var group_div = $('div#epm_templateadv_settings div#'+group.setting_id);
		if(!group_div.length && group.children.length > 0) {
			var settings_div = $('<div>')
				.attr({'id': group.setting_id})
				.addClass('setting_group')
				.css({'display': 'none'})
				.appendTo(fragment);

			var tableBody = $('<tbody>').appendTo($('<table>').appendTo(settings_div));
			group.children.forEach(function(setting) {
				if($(setting).attr('children') && !setting.children.length) {
					$('<tr>').append(
						$('<td>').text(setting.name),
						$('<td>').append(
							$('<input>').attr({
								'type': 'text',
								'name': 'advance_settings['+setting.setting_id+']'
							}).val(setting.value)
						)
					).appendTo(tableBody);
				}
			});

			sub_groups.push(group.children);
		}
	}, this);

	// We add each level of groups to the DOM as we encounter it
	$('div#epm_templateadv_settings div.epm_advanced_settings').append(fragment);

	// Then make sure to call it recursively with sub_groups if they exist
	sub_groups.forEach(function(sub_group) {
		this.populate_advanced_settings(sub_group);
	}, this);
};

// Add device buttons to the template
xepm.prototype.add_device_buttons = function(row, index, button, button_type) {
	var td = $(row).find('td');
	var inputs = $(row).find('input');
	var selects = $(row).find('select');
	if(button_type == 'device_buttons') {
		row.removeClass('device_buttons_row');
	} else if(button_type == 'device_buttons_line') {
		row.removeClass('device_buttons_line_row');
	}
	$(td[0]).text('Button ' + index);
	$(inputs[0]).val(button.label);   //label
	$(inputs[0]).attr('name', button_type + '[' + index + '][label]');
	$(inputs[1]).val(button.value);   //value
	$(inputs[1]).attr('name', button_type + '[' + index + '][value]');
	$(selects[0]).val(button.type);   //type
	$(selects[0]).attr('name', button_type + '[' + index + '][type]');
	$(selects[1]).val(button.line);   //line
	$(selects[1]).attr('name', button_type + '[' + index + '][line]');
	return row;
};

// Remove all data before adding new
xepm.prototype.clean_all_data = function() {
	$("table.device_buttons tbody").find('tr').slice(2).detach(); // clean dss buttons
	$("table.device_buttons_line tbody").find('tr').detach(); // clean line buttons
	$("div#epm_templateexp_module ul#attached_modules").find('li').detach(); // clean module tabs

	$("div#epm_templateexp_module div.attached_modules").detach(); // clean exp. module tables
	$('#epm_templateexp_module select#module_id').find('option').empty(); // Clean all the modules dropdown field
	$('div#epm_templateexp_module .epm_exp_module').css({'display':'none'}); // Hide exp. modules dropdown field
	$("div#modules div").remove(); // remove the attached modules
	$("div.epm_advanced_settings").find('select#xepm_groups').find('option').remove(); // clean advanced settings groups
	$("div.epm_advanced_settings").find('div.setting_group').detach(); // clean advanced settings

	$('div#epm_templatedevice_buttons table.device_buttons').css({'display':'none'}); // hide dss buttons table
	$('div.epm_template_dss').css({'display':'none'}); // hide dss buttons label
	$('div#epm_templatedevice_buttons table.device_buttons_line').css({'display':'none'}); // hide line buttons table
	$('div.epm_template_line').css({'display':'none'}); // hide line buttons label
};

// Add expansion buttons
xepm.prototype.add_exp_buttons = function(row, module_index, button, button_index) {
	var td = $(row).find('td');
	var inputs = $(row).find('input');
	var selects = $(row).find('select');
	row.removeClass('exp_buttons_row');
	$(td[0]).text('Button ' + (parseInt(button_index) + 1));
	$(inputs[0]).val(button.label);   //label
	$(inputs[0]).attr('name', 'expansion_buttons[' + module_index + '][' + button_index + '][label]');
	$(inputs[1]).val(button.value);   //value
	$(inputs[1]).attr('name', 'expansion_buttons[' + module_index + '][' + button_index + '][value]');
	$(selects[0]).val(button.type);   //type
	$(selects[0]).attr('name', 'expansion_buttons[' + module_index + '][' + button_index + '][type]');
	$(selects[1]).val(button.line);   //line
	$(selects[1]).attr('name', 'expansion_buttons[' + module_index + '][' + button_index + '][line]');
	return row;
};

// Add a module to this template
xepm.prototype.add_module = function(e) {
	xepm.attached_modules = null;
	if(typeof xepm.attached_modules != "undefined") {
		xepm.attached_modules = parseInt($("ul#attached_modules li").length);
	}
	var max_modules = $('#epm_templateexp_module #max_modules').val();
	var model_id = $('#epm_templategeneral #model_id').val();
	if(max_modules !== 'undefined' && !isNaN(parseInt(max_modules)) &&
		parseInt(max_modules) > 0 && model_id !== 'undefined' &&
		!isNaN(parseInt(model_id) && parseInt(model_id) > 0)
	) {
		if (xepm.attached_modules < parseInt(max_modules)) {
			var modules = $("select#module_id");
			var module_id = modules.val();
			if(parseInt(module_id) > 0) {
				$('button#xepm_add_module').prop('disabled', true);
				var module_name = modules.children(':selected').text();
				var conf_id = $('select#conf_id').val();
				var attached_modules = $('input[name="attached_modules[]"]');
				var modules = [];
				$.each(attached_modules, function(index, module) {
					modules[index] = module.value; // get all atached modules
				});
				modules.push(module_id); // append the current module
				$.ajax({
					type: "POST",
					url: xepm.url,
					dataType: 'json',
					data: {
						class: 'endpoint',
						method: 'add_module',
						modules: modules.join(","),
						model_id: model_id,
						configuration_type_id : conf_id
					},
					success: function (data) {
						xepm.populate_module_button_data(data.module_button_types, data.lines);
						if(data.exp_buttons != null) {
							$("<li/>", { text: module_name })
							.bind("click", function(event) { xepm.show_module(event.target); })
							.append(
								$("<i/>", { class : "fa fa-close btn" })
								.bind("click", function(event) { xepm.remove_module(event); }))
							.appendTo($("ul#attached_modules"));
							$("div#modules").append(
								$("<div>").css({'display' : 'block'}).addClass('attached_modules').append(
									$("<input>").attr({
										'type' : 'hidden',
										'name' : 'attached_modules[]',
										'value' : module_id
									}),
									xepm.add_exp_table(data.exp_buttons, xepm.attached_modules++)
								)
							);
							xepm.show_last_module();
						}
						$('button#xepm_add_module').prop('disabled', false);
					}
				});
			}
		}
	} else {
		$('button#xepm_add_module').prop('disabled', false);
	}
};

// Add expansion table to the template
xepm.prototype.add_exp_table = function(exp_buttons, module_index) {
	var table = $("<table>").addClass('template_exp_buttons').append(
		$("<thead>").append(
			$("<tr>").append(
				$("<th>").addClass('center'),
				$("<th>").addClass('center').html(
					$('#epm_templateexp_module #modules input#label_label').attr('text')
				),
				$("<th>").addClass('center').html(
					$('#epm_templateexp_module #modules input#type_label').attr('text')
				),
				$("<th>").addClass('center').html(
					$('#epm_templateexp_module #modules input#value_label').attr('text')
				),
				$("<th>").addClass('center').html(
					$('#epm_templateexp_module #modules input#line_label').attr('text')
				)
			)
		),
		$("<tbody>")
	);
	var row = $("table.epm_exp_buttons_table").find('tr.exp_buttons_row');
	$.each(exp_buttons, function(button_index, button) {
		var button_row = row.clone();
		button_row = xepm.add_exp_buttons(button_row, module_index, button, button_index);
		$(button_row).appendTo(table);
	});
	return table;
};

// Populate template data on predefined template selection
xepm.prototype.populate_models_on_template_select = function(template_id) {
	xepm.clean_all_data();
	if (template_id > 0) {
		var promise = $.ajax({
			type: "POST",
			url: xepm.url,
			dataType: 'json',
			data: {
				class: 'endpoint',
				method: 'populate_models_on_template_select',
				template_id: template_id
			}
		});
		promise.then(function (data) {
			[
				xepm.populate_model(data),
				xepm.populate_timezones(data),
				xepm.populate_configuration_type(data),
				xepm.populate_general_settings_tab(data),
				xepm.populate_data_on_template_select(template_id)
			]
		});
	}
};

// Populate template data
xepm.prototype.populate_data_on_template_select = function(template_id) {
  var promise = $.ajax({
		type: "POST",
		url: xepm.url,
		dataType: 'json',
		data: {
			class: 'endpoint',
			method: 'populate_on_template_select',
			template_id: template_id
		}
	});
	promise.then(function (data) {
		$('p.epm_select_model').css({'display':'none'});
		[
			xepm.populate_device_buttons_tab(data),
			xepm.populate_expansion_modules_tab(data),
			xepm.populate_advanced_settings_tab(data),
			xepm.add_edit_buttons(data.edit_buttons),
		],
		hideRightMenu();
	});
};

// Template general settings tab population
xepm.prototype.populate_general_settings_tab = function(data) {
	xepm.template_load = true; // prevent redundant ajax calls
	$('#epm_templategeneral #template_id').val(data.template.template_id);
	$('#epm_templategeneral #name').val(data.template.name);

	var brand_select = $('#epm_templategeneral #brand_id')
	var p = $('#epm_templategeneral p.epm_brand_name');
	if(!p.length) {
		p = $("<p>", {"class": "form-control-static epm_brand_name"});
	}
	p.html("<b>" + data.brand_name + "</b>");
	brand_select.parent().append(p);
	brand_select.hide();

	$('#epm_templategeneral #host_id').val(data.template.host_id);
	$('#epm_templategeneral #timezone_id').val(data.template.timezone_id);
	$('#epm_templategeneral #admin_password').val(data.template.admin_password);
};

// Template device buttons tab population
xepm.prototype.populate_device_buttons_tab = function(data) {
	xepm.populate_model_button_data(data.model_button_types, data.lines);
	if(!xepm.populate_device_buttons(data.device_buttons)) {
		$('p.epm_no_buttons').css({'display':'block'}); // no device buttons
	} else {
		$('p.epm_no_buttons').css({'display':'none'});
	}
};

// Template expansion modules tab population
xepm.prototype.populate_expansion_modules_tab = function(data) {
	xepm.populate_module_button_data(data.module_button_types, data.lines);
	xepm.populate_expansion_modules(data);

	if(data.modules != null && data.modules.length) {
		$.each(data.modules, function(index, module) {
			$("<li/>", { text: module.name })
			.bind("click", function(event) { xepm.show_module(event.target); })
			.append(
				$("<i/>", { class : "fa fa-close btn" })
				.bind("click", function(event) { xepm.remove_module(event); }))
			.appendTo($("ul#attached_modules"));
		});

		$.each(data.exp_buttons, function(module_index, exp_buttons) {
			$("div#modules").append(
				$("<div>").css({'display' : 'block'}).append(
					$("<input>").attr({
						'type' : 'hidden',
						'name' : 'attached_modules[]',
						'value' : data.modules[module_index].module_id
					}),
					xepm.add_exp_table(exp_buttons, module_index)
				)
			);
		});
		xepm.show_last_module();
	} else {
		$("div#modules div").remove(); // remove the attached modules
	}
};

// Add edit buttons to the page
xepm.prototype.add_edit_buttons = function(edit_buttons) {
	$('form#epm_template_form').find('div.frm-actions .buttons').html(edit_buttons);
};

// Template advanced settings tab population
xepm.prototype.populate_advanced_settings_tab = function(data) {
	xepm.populate_setting_groups(data.advanced_settings);
	xepm.populate_advanced_settings(data.advanced_settings);
	$("div.setting_group").first().show();
};

// Populate model button types and button lines
xepm.prototype.populate_model_button_data = function(types, lines) {
	var dss_selects = $("table.device_buttons tr.device_buttons_row").find('select');
	$(dss_selects).find('option').empty(); // Clean the options

	if('dss' in types) {
		dss_selects.eq(0).fill(types.dss, function(type) {
			this.val(type.ident);
			this.text(type.name);
		},['','']); // populate dss model button types
	}

	dss_selects.eq(1).fill(lines, function(line) {
		this.val(line.ident);
		this.text(line.name);
	},['','']); // populate model button lines

	var line_selects = $("table.device_buttons tr.device_buttons_line_row").find('select');
	$(line_selects).find('option').empty(); // Clean the options

	if('line' in types) {
		var line = types.line;
		line_selects.eq(0).fill(line, function(type) {
			this.val(type.ident);
			this.text(type.name);
		},['','']); // populate line model button types
	}

	line_selects.eq(1).fill(lines, function(line) {
		this.val(line.ident);
		this.text(line.name);
	},['','']); // populate model button lines
};

// Populate module button types and module button lines
xepm.prototype.populate_module_button_data = function(types, lines) {
	if(types != null) {
		var selects = $("table.epm_exp_buttons_table tr.exp_buttons_row").find('select');
		$(selects).find('option').empty(); // Clean the options
		selects.eq(0).fill(types, function(type) {
			this.val(type.ident);
			this.text(type.name);
		},['','']); // populate module button types
	}
	if(lines != null) {
		selects.eq(1).fill(lines, function(line) {
			this.val(line.ident);
			this.text(line.name);
		},['','']); // populate module button lines
	}
};

// Removes the module
xepm.prototype.remove_module = function(event) {
	event.stopPropagation();
	var element = event.target;
	if(confirm("Are you sure you want to remove this module ?")) {
		var module_index = $(element).closest("li").index();
		$("ul#attached_modules li").eq(module_index).remove();
		$("div#modules div").eq(module_index).remove();
		xepm.attached_modules = null;
		if(typeof xepm.attached_modules != "undefined") {
			xepm.attached_modules = parseInt($("ul#attached_modules li").length) - 1;
		}
		if (xepm.visible_module == module_index) { xepm.show_last_module(); }
		$('button#xepm_add_module').prop('disabled', false);
	}
};

// Toggle display exp. buttons support
xepm.prototype.show_exp_not_supported = function(show) {
	if(show) {
		$('p.epm_no_exp_buttons').css({'display':'block'});
	} else {
		$('p.epm_no_exp_buttons').css({'display':'none'});
	}
};

// Show the first module
xepm.prototype.show_first_module = function() {
	if ($("ul#attached_modules li").length > 0) { xepm.show_indexed_module(0); }
};
// Show the last module
xepm.prototype.show_last_module = function() {
	xepm.show_indexed_module($("ul#attached_modules li").length - 1);
};
// Show the clicked module
xepm.prototype.show_module = function(element) {
	xepm.show_indexed_module($(element).index());
};
// Show the indexed module
xepm.prototype.show_indexed_module = function(module_index) {
	if (module_index >= 0) {
		var tabs = $("ul#attached_modules li");
		var divs = $("div#modules div");
		tabs.removeClass("active");
		tabs.eq(module_index).addClass("active");
		divs.hide();
		divs.eq(module_index).show();
		xepm.visible_module = module_index;
	} else {
		delete xepm.visible_module;
	}
};
//TODO: might need to fix this
// Properly index modules on form submission
xepm.prototype.prepare_form = function() {
	$("div#modules div").each(function(module_index) {
		$(this).find("[name^='expansion_buttons']").each(function() {
			var element = $(this);
			var name = element.prop("name").replace(/(\w+\[)\d+(\]\[\d+\]\[\w+\])/, function(orig, prefix, suffix) {
				return prefix + module_index + suffix;
			});
			element.prop("name", name);
		});
	});
};

$(function(){
	$("select[id='xepm_groups']").bind("change keyup", function(event) {
		var group_id = $(event.target).val();
		var div = $("div[id='"+group_id+"']");
		var configuration_type_id = $("select[name='conf_id']").val();
		if(parseInt(group_id) > 0 && typeof div !== 'undefined' && parseInt(configuration_type_id) > 0) {
			$.ajax({
				type: "POST",
				url: xepm.url,
				dataType: 'json',
				data: {
					class: 'endpoint',
					method: 'settings_by_group_id',
					configuration_type_id: configuration_type_id,
					group_id: group_id
				},
				success: function (data) {
					xepm.populate_advanced_settings(data.advanced_settings);
					$("div.setting_group").hide();
					$("div[id='"+group_id+"']").show();
				}
			});
		}
	});

	$('table.device_buttons tbody').sortable({
		update: function(event, tr) {
			renumber_device_buttons(tr.item);
		}
	});
	$('table.device_buttons_line tbody').sortable({
		update: function(event, tr) {
			renumber_device_buttons(tr.item);
		}
	});
	$('table.template_exp_buttons tbody').sortable({
		update: function(event, tr) {
			renumber_exp_buttons(tr.item);
		}
	});
});

var xepm = new xepm();
xepm.assign_events();
