function firewall_del(element) {
	row = $(element).closest("tr");
	firewall_service_id = row.find("input[name='firewall_service_id[]']").val();
	if (firewall_service_id != null) {
		rules = row.closest("#tab_firewall").find("select[name='rule_service[]']");
		inuse = rules.map(function(inuse) {
			return inuse || $(this).val() == firewall_service_id;
		});
		if (inuse) {
			if (confirm(firewall_confirm_message)) {
				rules.each(function() {
					rule = $(this);
					if (rule.val() == firewall_service_id) {
						rule.closest("tr").remove();
					}
				});
			} else {
				return;
			}
		}
	}
	row.remove();
}

function firewall_add(element, key, fields, filler) {
	fields = fields.map(function (field) {
		switch (field.charAt(0)) {
			case "*": return $("<td>").append($("<select>").attr("name", field.substr(1)));
            case "!": return $("<td>").append($("<input>").attr("type", "text").attr("name", field.substr(1)+"["+rules_count+"]"));
            case "@": return $("<td>").append($("<input>").attr("type", "checkbox").attr("name", field.substr(1)+"[e"+rules_count+"]").
                attr('checked', 'checked').addClass("chk_new chk-repeat"));
			case "#": return $("<td>").
				append($("<span>").addClass("repeat-move btn btn-default btn-xs").
				append($("<i>").addClass("fa fa-arrows")));
		}
		return $("<td>").append($("<input>").attr("type", "text").attr("name", field));
	});
	uid = "#" + (new Date()).getTime();
	fields[0].prepend($("<input>").attr("type", "hidden").attr("name", key).attr("value", uid));
	button = $("<button>")
		.addClass("btn btn-danger btn-xs")
		.attr("type", "button")
		.click(function () {
			firewall_del(this);
		})
		.append(
			$("<i>")
				.addClass("glyphicon glyphicon-trash")
		);
	row = $("<tr>").append(fields).append($("<td>").append(button));
	$(element).closest("table").find("tbody").append(row);
    if(typeof fields[5] != 'undefined') {
        chk_box = fields[5].find('input[type=checkbox].chk-repeat');
        chk_box.bootstrapToggle('destroy');
        chk_box.bootstrapToggle({
            onstyle: 'success',
            width: 70
        });
    }
	if (filler) { filler(row); }
	$("#firewallrules table tbody").sortable();
}

function firewall_fill(element, options) {
	selected = element.value;
	$(element).empty();

	for (var i = 0; i < options.length; ++i) {
		element.options.add(new Option(options[i].text, options[i].value));
	}
	element.value = selected;
}

function firewall_services() {
	services = [];
	$("#firewallservices tbody tr").each(function() {
		id = $(this).find("[name='firewall_service_id[]']").val();
		services.push(new Option($(this).find("[name='service_name[]']").val(), id));
	});
	services.sort(function (a, b) {
		return a.text.toLowerCase().localeCompare(b.text.toLowerCase());
	});
	return services;
}

function make_array(objects) {
	var array = [];
	for (key in objects) {
		array.push(new Option(objects[key], key));
	}
	array.sort(function (a, b) {
		return a.text.toLowerCase().localeCompare(b.text.toLowerCase());
	});
	return array;
}

function firewall_rule(element) {
	firewall_add(
		element,
		"firewall_rule_id[]",
		[ "#", "*rule_service[]", "rule_source[]",  "!rule_destination", "*rule_action[]", "@rule_enabled" ],
		function (row) {
			services = firewall_services();
			row.find("[name='rule_service[]']").each(function() {
				firewall_fill(this, services);
			});
			actions = make_array(firewall_actions);
			row.find("[name='rule_action[]']").each(function() {
				firewall_fill(this, actions);
			});
		}
	);
    rules_count++;
}

function firewall_service(element) {
	firewall_add(
		element,
		"firewall_service_id[]",
		[ "service_name[]", "*service_protocol[]", "service_port[]" ],
		function (row) {
			protocols = make_array(firewall_protocols)
			row.find("[name='service_protocol[]']").each(function() {
				firewall_fill(this, protocols);
			});
		}
	);
}

function firewall_whitelist(element) {
	firewall_add(
		element,
		"firewall_whitelist_id[]",
		[ "whitelist_host[]", "whitelist_description[]" ]
	);
}

if (!window.firewall_hooked) {
	window.firewall_hooked = true;
	$("#pbx-content").on("click", "[href='#firewallrules']", function () {
		services = firewall_services();
        rules_count = $("#firewallrules").find("[name='rule_service[]']").length;
		$("#firewallrules").find("[name='rule_service[]']").each(function() {
			firewall_fill(this, services);
		});
		actions = make_array(firewall_actions);
		$("#firewallrules").find("[name='rule_action[]']").each(function() {
			firewall_fill(this, actions);
		});
	});
	$("#pbx-content").on("click", "[href='#firewallservices']", function () {
		services = firewall_services();
		protocols = make_array(firewall_protocols);
		$("#firewallservices").find("[name='service_protocol[]']").each(function() {
			firewall_fill(this, protocols);
		});
	});
}

$("#firewallrules table tbody span.repeat-move").bind('mousedown', function() {
	var disabled = $("#firewallrules table tbody").sortable();
	$("#firewallrules table tbody").sortable("enable");
});
$("#firewallrules table tbody span.repeat-move").bind('mouseup', function() {
	var disabled = $("#firewallrules table tbody").sortable("option", "disabled");
	$("#firewallrules table tbody").sortable("disable");
});
